/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.distributions;

import ikr.simlib.random.RandomNumberGenerator;

/**
 * <code>Distribution</code> is the common base class for all distributions.
 * Distributions may either share a common RNG, or use their own RNG. The base
 * class manages RNGs for use by derived classes.
 */
public abstract class Distribution {

   /**
    * There should not be any need to change the RNG of a distribution. If you
    * need a different RNG you need to create a new distribution object.
    */
   protected final RandomNumberGenerator rng;

   public Distribution() {
      rng = getDefaultRNG();
   }

   public Distribution(RandomNumberGenerator rng) {
      this.rng = rng;
   }

   public RandomNumberGenerator getRandomNumberGenerator() {
      return rng;
   }

   public static RandomNumberGenerator getDefaultRNG() {
      return RandomNumberGenerator.getSystemRNG();
   }

   /**
    * The default behavior is to do nothing. Some state dependent distributions
    * override the function
    */
   public void reset() {
   }
}
