/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.distributions.mapped;

import ikr.simlib.random.RandomNumberGenerator;

/**
 * This distribution returns one of two items depending on the probability for
 * the first item.
 * 
 * @param <I>
 *           type of distribution values
 * 
 */
public class MappedBernoulliDistribution<I> extends MappedDistribution<I> {

   public final I firstItem;
   public final I secondItem;
   private double firstProbability;

   public MappedBernoulliDistribution(I firstItem, double firstProbability, I secondItem, RandomNumberGenerator rng) {
      super(rng);
      this.firstItem = firstItem;
      this.secondItem = secondItem;
      this.firstProbability = firstProbability;
   }

   public MappedBernoulliDistribution(I firstItem, double firstProbability, I secondItem) {
      this(firstItem, firstProbability, secondItem, getDefaultRNG());
   }

   @Override
   public I next() {
      if (rng.next() <= firstProbability) {
         return firstItem;
      } else {
         return secondItem;
      }
   }

   public double getFirstProbability() {
      return firstProbability;
   }

   public void setFirstProbability(double firstProbability) {
      this.firstProbability = firstProbability;
   }
}
