/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.entities.multiplexers;

import ikr.simlib.model.SimNode;
import ikr.simlib.ports.Port;
import ikr.simlib.ports.input.InputPort;

/**
 * PriorityMultiplexer is roughly the same as a standard multiplexer. However,
 * looking for new messages always starts at the port with the highest priority.
 * The ports create on construction obtain decreasing priorities, i.e. "input 1"
 * has highest priority, while "input N" has lowest priority. Ports added later
 * via <code>AddPort</code> get lower priority.
 */
public class PriorityMultiplexer extends StdMultiplexer {

   public PriorityMultiplexer(int noOfPorts, SimNode ownNode) {
      super(noOfPorts, ownNode);
   }

   public PriorityMultiplexer(SimNode ownNode) {
      super(ownNode);
   }

   @Override
   public boolean handleIsMessageAvailable(Port port) {
      for (InputPort p : inputPorts) {
         if (p.isMessageAvailable()) {
            currentPort = p;
            return true;
         }
      }

      return false;
   }

}
