/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.entities.phases;

import ikr.simlib.distributions.Distribution;
import ikr.simlib.distributions.continuous.ContinuousDistribution;
import ikr.simlib.events.time.Duration;
import ikr.simlib.exceptions.SimulationException;
import ikr.simlib.messages.Message;
import ikr.simlib.model.SimNode;
import ikr.simlib.parameters.Parameters;
import ikr.simlib.parameters.reflection.ReflectionConstructable;

/**
 * The StdPhase class uses the same distribution for all messages.
 */
public class StdPhase extends Phase {
   
   private static final String SERVICE_TIME_DIST = "ServiceTimeDist";
   
   /** as required by {@link ReflectionConstructable} */
   public static StdPhase createInstance(SimNode ownNode, Parameters pars) {
      ContinuousDistribution serviceTime = pars.get(ownNode, SERVICE_TIME_DIST).asInstance(ContinuousDistribution.class, ownNode.createChildNode(SERVICE_TIME_DIST), pars, Distribution.getDefaultRNG());
      return new StdPhase(serviceTime, ownNode);
   }

   protected ContinuousDistribution serviceTime;

   public StdPhase(ContinuousDistribution d, SimNode ownNode) {
      super(ownNode);
      serviceTime = d;
   }

   protected StdPhase(SimNode ownNode) {
      super(ownNode);
   }

   @Override
   protected Duration getMessageProcessingDuration(Message msg) {
      if (serviceTime == null)
         throw new SimulationException("undefined IAT distribution in " + simNode.getFullName());

      return Duration.fromSeconds(serviceTime.next());
   }
}
