/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.entities.sinks;

import ikr.simlib.entities.Entity;
import ikr.simlib.messages.Message;
import ikr.simlib.model.SimNode;
import ikr.simlib.ports.input.InputPort;

/**
 * The task of a traffic sink is to delete messages on the heap at the end of a chain of passing
model components. For this purpose the class <code>Sink</code> has been derived from the {@link ikr.simlib.entities.Entity} and is
implemented with the help of <code>InputMessageHandler</code>. It communicates with the preceding
model component via the input port (class {@link ikr.simlib.ports.input.InputPort})
 * This component can be used as sink for all messages. All received messages
 * are destroyed by this entity.
 */
public class Sink extends Entity {

   private InputPort inputPort;

   public Sink(SimNode ownNode) {
      super(ownNode);

      inputPort = new InputPort(this) {
         @Override
         protected void handleMessageIndication(Message msg) {
            Sink.this.handleMessageIndication(msg);
         }
      };
   }

   protected void handleMessageIndication(Message message) {
      inputPort.getMessage();
   }

   public InputPort getInput() {
      return inputPort;
   }
}
