/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.events;

/**
 * Interface describing the object an entity gets when posting an event. This
 * can be used to query the state of the event and to cancel the event.
 * <p>
 * At any point in time, exactly one of the methods {@link #isPending()},
 * {@link #hasBeenCancelled()}, or {@link #hasBeenExecuted()} will return true.
 */
public interface EventToken {
   /**
    * @return true if the event (with the specified time of execution) is in the
    *         calendar, false if it has been executed or cancelled
    */
   boolean isPending();

   /**
    * @return true if the event (with the specified time of execution) has been
    *         executed, false if it is still pending or has ben cancelled.
    */
   boolean hasBeenExecuted();

   /**
    * @return true if the event (with the specified time of execution) has been
    *         cancelled, false if it has been executed or is still pending
    */
   boolean hasBeenCancelled();

   /**
    * Cancel the event, i.e. execute its onCancel method now, and do not execute
    * it's onExecute method at the specified time of execution.
    */
   void cancel();
}