/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.exceptions;

import java.lang.Thread.UncaughtExceptionHandler;

public class ExitExceptionHandler implements UncaughtExceptionHandler {

   /**
    * Call this method to make sure that the program terminates if any thread
    * throws an exception. Default behaviour is to terminate the respective
    * thread, which is typically not wanted for simulations.
    */
   public static void setAsDefaultUncaughtExceptionHandler() {
      Thread.setDefaultUncaughtExceptionHandler(new ExitExceptionHandler());
   }

   private ExitExceptionHandler() {

   }

   @Override
   public void uncaughtException(Thread t, Throwable e) {
      System.err.println("Exception ocurred in Thread " + t.getName() + ":");
      e.printStackTrace(System.err);
      System.exit(1);
   }

}
