/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

/** 
 * <h1>Model Components</h1>
 * <br>
A major advantage of the IKR Simulation Library is the easy construction of a model from
model components (e.g. queues, service units) that are then connected together with the help of
the port concept.<br>
<br>
<h1>General Classes</h1>
<h2>Hierarchical Models: Class SimNode</h2>
The IKR SimLib supports the building of hierarchical models. Therefore, there is an interface
to build a model hierarchy, which is called {@link ikr.simlib.model.SimNode}. The top node of the hierarchy belongs to
an object of the class {@link ikr.simlib.model.Model}. All other nodes of the hierarchy can belong to objects of arbitrary
type.<br>
There is a default implementation of a {@link ikr.simlib.model.SimNode} called {@link ikr.simlib.model.StdSimNode}, which already implements
the methods listed in {@link ikr.simlib.model.SimNode}.<br>
<br>
Every simulation program has one single instance of the class {@link ikr.simlib.model.SimNodeManager}. This
object knows the root of the model hierarchy and can traverse the hierarchy for purpose of
printing.<br>
<br>
<h2>Model Component Base Class: Class Entity</h2>
Model components can be derived from the class {@link ikr.simlib.entities.Entity}.<br>
Within the simulation library, several model components already exist which have been
derived from {@link ikr.simlib.entities.Entity}. These classes will be introduced in the following.<br>
<br>
<h2>Complete Model: Class Model</h2>
At the top of the hierarchically ordered model components, there is a model component
derived from {@link ikr.simlib.model.Model}.<br>
<br>
<h2>Traffic End Points</h2>
Generators<br>
- See {@link ikr.simlib.entities.generators.Generator}<br>
Sinks<br>
- See {@link ikr.simlib.entities.sinks.Sink}<br>
<br>
<h2>Service Components</h2>
Server<br>
- See {@link ikr.simlib.entities.phases.Phase}<br>
Queue<br>
- See {@link ikr.simlib.entities.queues}<br>
<br>
<h2>Connector Components</h2>
Multiplexer<br>
- See {@link ikr.simlib.entities.multiplexers.Multiplexer}<br>
Demultiplexer<br>
- See {@link ikr.simlib.entities.demultiplexers.Demultiplexer}<br>
Expander<br>
- See {@link ikr.simlib.entities.branches.Expander}<br>
Branches<br>
- See {@link ikr.simlib.entities.branches.Branch}<br>

<br>
<h1>Port Concept</h1>
Model components communicate with each other using messages / cells / packets via so-called
ports. Therefore, the model components have a defined interface which increases their re-usability.

@see ikr.simlib.messages.Message
@see ikr.simlib.ports.Port






 */
package ikr.simlib.model;