/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

/** 
 * <h1>IKR Simulation Library (IKR SimLib)</h1>
 * <br>
 * <h2>1.1 History</h2>
 * The IKR Simulation Library is a tool, which is mainly used for event-driven simulation of
complex systems in the area of communications engineering. Originally, Hartmut Kocher
designed an object-oriented version of the IKR SimLib in 1993 during his dissertation [1] and
implemented it in C++. Since this original design, we enhanced and improved the IKR SimLib
continously.
<br>In 2008, we ported the IKR SimLib to Java while keeping all concepts and mechanisms of the
existing C++ class library. Today, two editions of the IKR SimLib are available: The C++ Edition
and the Java Edition. Each edition comes as a separate class library. The IKR SimLib is
publicly available under the GNU Lesser General Public License (LGPL) and thus allows
changes within the libraries itself as well as proprietary programs to use it.
<br>In the last years, we have successfully used the IKR SimLib for performance evaluation in various
projects from different areas in communication network research, e.g. IP, ATM, photonic,
mobile, and signaling networks.
 * <br>
 * <h2>1.2 Conceptual Structure</h2>
 * We structure the IKR Simulation Library into three main parts (Fig. 1). Basic concepts
include simulation support mechanisms like event handling (see {@link ikr.simlib.events}), simulation IKR control
(See {@link ikr.simlib.control}), distribution-oriented random number generation (See {@link ikr.simlib.distributions}) and tools to statistically
evaluate measured values (See {@link ikr.simlib.statistics}) as well as reading parameters (See {@link ikr.simlib.parameters}) and
printing simulation results are provided.<br>
Beyond that, the IKR Simulation Library contains concepts for constructing hierarchical models
from individual components (See {@link ikr.simlib.model}) that communicate with each other by exchanging
messages (See {@link ikr.simlib.messages.Message}). This message exchange occurs using so-called ports (See {@link ikr.simlib.ports.Port}),
which are used to define an external interface of a model component. Then, we can connect
this interface to meters (See {@link ikr.simlib.meters}), which allow a simple determination of measurement values.<br>
<br>
 * <center><img src="{@docRoot}/ikr/simlib/doc-files/IKRSimLib_BasicStructure.svg" width="600" alt="Structure of the IKR Simulation Library"><br>Structure of the IKR Simulation Library</center>
 * <br><br>
 * <h2>1.3 Naming Conventions</h2>
 * In order to ensure that the source code of the IKR SimLib is easy to read and maintain, we follow
Sun's Code Conventions for the Java Programming Language (see http://java.sun.com/
docs/codeconv/html/CodeConvTOC.doc.html). Depending on the type, the first letter of a
camel case compound may or may not be capitalized. For example class names use a capitalized
letter (e.g., Queue), and variables and attributes a lowercase letter (e.g., name).
The identifier of an element should be self-explanatory (e.g., maxLength, routingManager).
If the element's name consists of several individual words, these are preferably written
together, where each new part of the word begins with a capitalized letter.
 * 
 * <br><br><br>
 * [1] H. KOCHER: Entwurf und Implementierung einer Simulationsbibliothek unter Anwendung
objektorientierter Methoden, Dissertation, Institute of Communication Networks
and Computer Engineering, University of Stuttgart, 1993.
 * 
 */
package ikr.simlib;