/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.parameters.fileparser.tokens;

import java.text.CharacterIterator;
import java.text.StringCharacterIterator;
import java.util.LinkedList;
import java.util.List;

public class TokenExpander {

   public static final char SINGLE_QUOTATION_MARK = '\'';
   public static final char DOUBLE_QUOTATION_MARK = '\"';

   public static List<Token> getParts(String string, final char OPENING_BRACKET, final char CLOSING_BRACKET, final char COMMENT) {

      List<Token> parts = new LinkedList<Token>();
      StringCharacterIterator it = new StringCharacterIterator(string);

      for (char ch = it.first(); ch != CharacterIterator.DONE; ch = it.next()) {

         if (ch == COMMENT) {
            break; // ignore this and all following characters

         } else if (ch == OPENING_BRACKET) {
            parts.add(new StartArrayToken(ch));

         } else if (ch == CLOSING_BRACKET) {
            parts.add(new EndArrayToken(ch));

         } else if (ch == SINGLE_QUOTATION_MARK) {
            parts.add(new ScalarToken(readSingleQuotedString(it)));

         } else if (ch == DOUBLE_QUOTATION_MARK) {
            parts.add(new ScalarToken(readDoubleQuotedString(it)));

         } else if (!Character.isWhitespace(ch)) {
            parts.add(new ScalarToken(readUnquotedString(it, OPENING_BRACKET, CLOSING_BRACKET)));
         }
      }

      return parts;
   }

   private static String readSingleQuotedString(StringCharacterIterator it) {
      StringBuilder s = new StringBuilder();

      assert it.current() == SINGLE_QUOTATION_MARK;

      while (it.next() != SINGLE_QUOTATION_MARK) {
         s.append(it.current());
      }

      assert it.current() == SINGLE_QUOTATION_MARK;
      it.next();

      return s.toString();
   }

   private static String readDoubleQuotedString(StringCharacterIterator it) {
      StringBuilder s = new StringBuilder();

      assert it.current() == DOUBLE_QUOTATION_MARK;

      while (it.next() != DOUBLE_QUOTATION_MARK) {
         s.append(it.current());
      }

      assert it.current() == DOUBLE_QUOTATION_MARK;
      it.next();

      return s.toString();
   }

   private static String readUnquotedString(StringCharacterIterator it, final char OPENING_BRACKET, final char CLOSING_BRACKET) {
      StringBuilder s = new StringBuilder();
      char ch = it.current();

      while (ch != CharacterIterator.DONE && !Character.isWhitespace(ch) && ch != OPENING_BRACKET && ch != CLOSING_BRACKET) {
         s.append(ch);
         ch = it.next();
      }
      it.previous();

      return s.toString();
   }

}
