/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.parameters.keys;

import ikr.simlib.parameters.NamingConstants;
import ikr.simlib.parameters.ParameterException;

public abstract class KeyQueryBase {

   protected static final String PART_REGEX = "[a-zA-Z0-9_*]+";
   protected static final String WILDCARD = "*";

   protected final String[] parts;

   protected KeyQueryBase(String query) {
      // split string into parts
      parts = query.split(NamingConstants.DELIMITER_REGEX);

      // check parts
      for (int i = 0; i < parts.length; i++) {
         if (!parts[i].matches(PART_REGEX))
            throw new ParameterException("key part " + parts[i] + " doesn't match regex " + PART_REGEX);
      }
   }

   @Override
   public String toString() {
      StringBuilder string = new StringBuilder();

      // build key string from key parts and the delimiter
      for (int index = 0; index < parts.length; index++) {
         if (index > 0)
            string.append(NamingConstants.DELIMITER);

         string.append(parts[index]);
      }

      return string.toString();
   }

   @Override
   public boolean equals(Object obj) {
      if (obj instanceof KeyQueryBase) {
         KeyQueryBase other = (KeyQueryBase) obj;

         return other.toString().equals(toString());

      } else {
         return false;
      }
   }

   @Override
   public int hashCode() {
      return toString().hashCode();
   }
}
