/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.parameters.reflection;

/**
 * This is a marker interface for classes which can be loaded by reflection.
 * Specifying that a class implements this interface commits the programmer to
 * implementing a matching static createInstance() method in all derived
 * (non-abstract) classes.
 * <p>
 * Due to Java's type erasure, only the number of arguments can be used to
 * distinguish several implemented interfaces derived from
 * {@link ReflectionConstructable}. Therefore, {@link ReflectionConstructable1}
 * to {@link ReflectionConstructable10} have been created. If a class inherits
 * {@link ReflectionConstructable2} and {@link ReflectionConstructable3}, it
 * must implement the appropriate two createInstance methods. If it shall be
 * constructable using different parameters, it just can implement
 * {@link ReflectionConstructable4}, if necessary with superset of the desired
 * parameters.
 * <p>
 * Java does not allow an interface to enforce a static method. Therefore, a
 * custom annotation processor {@link ReflectionConstructableProcessor} can be
 * used to check for the correct implementation in the derived classes at
 * compile time. However, this check is optional. If not implemented correctly,
 * this could lead to runtime errors when loading a class via reflection which
 * does not implement the correct static method.
 */
public interface ReflectionConstructable {
   public static final String CREATE_INSTANCE_METHOD_NAME = "createInstance";
}
