/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.parameters.values;

import ikr.simlib.parameters.reflection.ReflectionConstructable;
import ikr.simlib.parameters.reflection.ReflectionConstructable1;
import ikr.simlib.parameters.reflection.ReflectionConstructable10;
import ikr.simlib.parameters.reflection.ReflectionConstructable2;
import ikr.simlib.parameters.reflection.ReflectionConstructable3;
import ikr.simlib.parameters.reflection.ReflectionConstructable4;
import ikr.simlib.parameters.reflection.ReflectionConstructable5;
import ikr.simlib.parameters.reflection.ReflectionConstructable6;
import ikr.simlib.parameters.reflection.ReflectionConstructable7;
import ikr.simlib.parameters.reflection.ReflectionConstructable8;
import ikr.simlib.parameters.reflection.ReflectionConstructable9;
import ikr.simlib.parameters.reflection.ReflectionLoader;

public class Scalar extends Value {

   public final String value;

   public Scalar(String value) {
      this.value = value;
   }

   @Override
   public <T extends Enum<T>> T asEnum(Class<T> enumClass) {
      return Enum.valueOf(enumClass, value);
   }

   @Override
   public boolean asBoolean() {
      return Boolean.valueOf(value);
   }

   @Override
   public String asString() {
      return value;
   }

   @Override
   public String[] asStringVector() {
      String[] vector = new String[1];
      vector[0] = value;
      return vector;
   }

   @Override
   public String[][] asStringMatrix() {
      String[][] matrix = new String[1][1];
      matrix[0][0] = value;
      return matrix;
   }

   @Override
   public int asInteger() {
      return Integer.valueOf(value);
   }

   @Override
   public int[] asIntegerVector() {
      int[] vector = new int[1];
      vector[0] = Integer.valueOf(value);
      return vector;
   }

   @Override
   public int[][] asIntegerMatrix() {
      int[][] matrix = new int[1][1];
      matrix[0][0] = Integer.valueOf(value);
      return matrix;
   }

   @Override
   public double asDouble() {
      return Double.valueOf(value);
   }

   @Override
   public double[] asDoubleVector() {
      double[] vector = new double[1];
      vector[0] = Double.valueOf(value);
      return vector;
   }

   @Override
   public double[][] asDoubleMatrix() {
      double[][] matrix = new double[1][1];
      matrix[0][0] = Double.valueOf(value);
      return matrix;
   }

   @Override
   public long asLong() {
      return Long.valueOf(value);
   }

   @Override
   public long[] asLongVector() {
      long[] vector = new long[1];
      vector[0] = Long.valueOf(value);
      return vector;
   }

   @Override
   public long[][] asLongMatrix() {
      long[][] matrix = new long[1][1];
      matrix[0][0] = Long.valueOf(value);
      return matrix;
   }

   @Override
   public String toString() {
      return value;
   }

   @Override
   public <P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, T extends ReflectionConstructable10<P0, P1, P2, P3, P4, P5, P6, P7, P8, P9>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3, P4 p4, P5 p5, P6 p6, P7 p7, P8 p8, P9 p9) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3, p4, p5, p6, p7, p8, p9);
   }

   @Override
   public <P0, P1, P2, P3, P4, P5, P6, P7, P8, T extends ReflectionConstructable9<P0, P1, P2, P3, P4, P5, P6, P7, P8>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3, P4 p4, P5 p5, P6 p6, P7 p7, P8 p8) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3, p4, p5, p6, p7, p8);
   }

   @Override
   public <P0, P1, P2, P3, P4, P5, P6, P7, T extends ReflectionConstructable8<P0, P1, P2, P3, P4, P5, P6, P7>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3, P4 p4, P5 p5, P6 p6, P7 p7) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3, p4, p5, p6, p7);
   }

   @Override
   public <P0, P1, P2, P3, P4, P5, P6, T extends ReflectionConstructable7<P0, P1, P2, P3, P4, P5, P6>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3, P4 p4, P5 p5, P6 p6) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3, p4, p5, p6);
   }

   @Override
   public <P0, P1, P2, P3, P4, P5, T extends ReflectionConstructable6<P0, P1, P2, P3, P4, P5>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3, P4 p4, P5 p5) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3, p4, p5);
   }

   @Override
   public <P0, P1, P2, P3, P4, T extends ReflectionConstructable5<P0, P1, P2, P3, P4>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3, P4 p4) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3, p4);
   }

   @Override
   public <P0, P1, P2, P3, T extends ReflectionConstructable4<P0, P1, P2, P3>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2, P3 p3) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2, p3);
   }

   @Override
   public <P0, P1, P2, T extends ReflectionConstructable3<P0, P1, P2>> T asInstance(Class<T> clazz, P0 p0, P1 p1, P2 p2) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1, p2);
   }

   @Override
   public <P0, P1, T extends ReflectionConstructable2<P0, P1>> T asInstance(Class<T> clazz, P0 p0, P1 p1) {
      return ReflectionLoader.newInstance(value, clazz, p0, p1);
   }

   @Override
   public <P0, T extends ReflectionConstructable1<P0>> T asInstance(Class<T> clazz, P0 p0) {
      return ReflectionLoader.newInstance(value, clazz, p0);
   }

   @Override
   public <T extends ReflectionConstructable> T asInstance(Class<T> clazz) {
      return ReflectionLoader.newInstance(value, clazz);
   }

}
