/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.ports.input;

import ikr.simlib.entities.Entity;
import ikr.simlib.messages.Message;

/**
 * A StdNonBlockingInputPort fetches a message using GetMessage() as soon as it
 * receives a message indication. The handler is then called with the received
 * message as parameter. This makes the usage of this port very easy, as one
 * does not need to deal with the Handle-methods. The output port counterpart is
 * the NonBlockingOutputPort or the SynchronousOutputPort.
 */
public class NonBlockingInputPort extends InputPort {

   public <E extends Entity & MessageReceiver> NonBlockingInputPort(E owner, String portName) {
      super(owner, portName);
   }

   public <E extends Entity & MessageReceiver> NonBlockingInputPort(E owner) {
      this(owner, INPUT_PORT_NAME);
   }

   @Override
   protected void handleMessageIndication(Message msg) {
      ((MessageReceiver) owner).receiveMessage(getMessage());
   }
}
