/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.ports.output;

import ikr.simlib.entities.Entity;
import ikr.simlib.messages.Message;
import ikr.simlib.ports.PortException;

/**
 * SynchronousOutputPort is even more restrictive than NonBlockingOutputPort,
 * because it enforces that the message is actually sent during the call to
 * SendMessage.
 * 
 * <p>
 * Message must be fetched by receiving port <strong>during</strong>
 * SendMessage() execution.
 * </p>
 */
public class SynchronousOutputPort extends OutputPort {

   protected Message message;

   public SynchronousOutputPort(Entity owner, String portName) {
      super(owner, portName);
   }

   public SynchronousOutputPort(Entity owner) {
      this(owner, OUTPUT_PORT_NAME);
   }

   public void sendMessage(Message m) {
      message = m; // save it

      messageIndication(m); // tell next port

      if (message != null) {
         throw new PortException("Message has not been sent");
      }
   }

   @Override
   protected Message handleGetMessage() {
      if (message == null) {
         throw new PortException("No message available");
      }

      Message m = message;
      message = null;

      return m;
   }

   @Override
   protected boolean handleIsMessageAvailable() {
      return message != null;
   }
}
