/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.result;

import java.util.ArrayDeque;
import java.util.Iterator;

public class PathHelper {
   public static final String PATH_DELIMITER = new String(":");
   private final ArrayDeque<String> stack = new ArrayDeque<String>();

   public void enterSubTree(String name) {
      stack.push(name);
   }

   public void leaveSubTree() {
      stack.pop();
   }

   public String getPathName() {
      StringBuilder pathName = new StringBuilder();
      final Iterator<String> iter = stack.descendingIterator();
      while (iter.hasNext()) {
         if (pathName.length() > 0)
            pathName.append(PATH_DELIMITER);
         pathName.append(iter.next());
      }
      return pathName.toString();
   }

   public String getPathName(String name) {
      String path = getPathName();
      if (path.length() > 0)
         path += PATH_DELIMITER;
      path += name;
      return path;
   }

}
