/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.result.filtering;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.util.LinkedList;
import java.util.List;

public class Filter {

   // private static Logger logger =
   // Logger.getLogger(ikr.simlib.result.Filter.class.getName());

   private static Filter instance = null;

   private List<FilterRule> rules;
   private boolean defaultBehavior;

   private Filter() {
      rules = new LinkedList<FilterRule>();
      defaultBehavior = true;
   }

   public static Filter getInstance() {
      if (instance == null) {
         instance = new Filter();
      }

      return instance;
   }

   public void addRule(FilterRuleType type, String regex) {
      rules.add(new FilterRule(type, regex));
   }

   public boolean printResult(String pathName) {
      // check filter rules
      for (FilterRule rule : rules) {
         if (pathName.matches(rule.regex)) {
            switch (rule.type) {
            case INCLUDE:
               // logger.info("    Printing result: " + pathName);
               return true;
            case EXCLUDE:
               // logger.info("NOT Printing result: " + pathName);
               return false;
            }
         }
      }

      return defaultBehavior;
   }

   public void readFilterStream(Reader filterStream) {
      BufferedReader reader = new BufferedReader(filterStream);
      String line;
      do {
         try {
            line = reader.readLine();
         } catch (IOException e) {
            line = null;
         }

         if (line != null) {
            String[] parts = line.split(" ");

            // default behavior
            if (parts[0].equalsIgnoreCase("default")) {
               // logger.info("Adding default rule: " + parts[1]);
               defaultBehavior = parts[1].equalsIgnoreCase("include");
            }

            // include rule
            if (parts[0].equalsIgnoreCase("include")) {
               // logger.info("Adding include rule: " + parts[1]);
               addRule(FilterRuleType.INCLUDE, manipulateRegExp(parts[1]));
            }

            // exclude rule
            if (parts[0].equalsIgnoreCase("exclude")) {
               // logger.info("Adding exclude rule: " + parts[1]);
               addRule(FilterRuleType.EXCLUDE, manipulateRegExp(parts[1]));
            }
         }

      } while (line != null);
   }

   private static String manipulateRegExp(String regexp) {
      String expandedRegexp = regexp.replaceAll("\\.", "[A-Za-z_0-9]");

      if (regexp.endsWith(".*")) {
         return "^" + expandedRegexp + "$";
      } else {
         return "^" + expandedRegexp + ".*$";
      }
   }

}
