/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.statistics.distribution.trace;

import ikr.simlib.model.SimNode;
import ikr.simlib.result.ResultReader;
import ikr.simlib.result.ResultWriter;
import ikr.simlib.result.exceptions.ImportException;
import ikr.simlib.result.exceptions.PrintException;
import ikr.simlib.statistics.distribution.trace.data.DataSource;
import ikr.simlib.statistics.distribution.trace.data.DataStorage;
import ikr.simlib.statistics.distribution.trace.data.TraceDataSource;
import ikr.simlib.statistics.distribution.trace.data.TraceDataStorage;
import ikr.simlib.statistics.distribution.trace.quantile.QuantileDescription;

import java.io.File;

/**
 * Implementation of {@link DistributionStatisticBase} which stores the values
 * on disk. When used with Export / Import, the absolute file names of the
 * binary files are written to the xml file.
 */
public class TracingDistributionStatistic extends DistributionStatisticBase {

   public TracingDistributionStatistic(SimNode ownNode, int numberOfQuantiles, boolean writeDropDistributions) {
      super(ownNode, numberOfQuantiles, writeDropDistributions);
   }

   public TracingDistributionStatistic(SimNode ownNode, int numberOfQuantiles) {
      super(ownNode, numberOfQuantiles);
   }

   public TracingDistributionStatistic(SimNode ownNode, QuantileDescription quantiles, boolean writeDropDistributions) {
      super(ownNode, quantiles, writeDropDistributions);
   }

   @Override
   protected DataStorage createNewDataStorage(int batchNumber) {
      return new TraceDataStorage(this.simNode, batchNumber, true);
   }

   /**************************************************************************
    * import & export
    ***************************************************************************/

   private final static String EXPORT_TRACE_FILE_NAME = "TraceFile";

   @Override
   void exportBatchData(ResultWriter writer, DataSource lastBatchData) throws PrintException {
      writer.writeString(EXPORT_TRACE_FILE_NAME, ((TraceDataSource) lastBatchData).getFile().getAbsolutePath());
   }

   @Override
   TraceDataSource importBatchData(ResultReader reader) throws ImportException {
      final File traceFile = new File(reader.readString(EXPORT_TRACE_FILE_NAME));
      return new TraceDataSource(traceFile);
   }
}
