/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.statistics.distribution.trace.data;

/**
 * Memory requirements: Each sample contains a value and a weight (both of type
 * double). Including the object header (12 to 16 bytes), a sample consumes 28
 * to 32 bytes of heap space. In addition, the ArrayList requires 4 to 8 bytes
 * per entry for the reference. In total, each sample consumes 32 bytes (32bit)
 * to 40 bytes (64bit).
 */
public class Sample implements Comparable<Sample> {
   public static final int SIZE_BYTES = 40;

   public final double value, weight;

   public Sample(double val, double weight) {
      this.value = val;
      this.weight = weight;
   }

   @Override
   public int compareTo(Sample o) {
      return Double.compare(value, o.value);
   }

   @Override
   public String toString() {
      return "value=" + value + " weight=" + weight;
   }

}