/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.statistics.support;

import ikr.simlib.exceptions.SimulationException;

public class LinBucketUtility extends BucketUtility {

   private final double width;

   public LinBucketUtility(double min, double max, int noOfBuckets) {
      super(min, max, noOfBuckets);

      width = max - min;
   }

   @Override
   public int getBucket(double condVal) {
      if (!isInRange(condVal)) {
         throw new SimulationException("Conditional value out of range");
      }

      int bucket = (int) (getArraySize() * (condVal - getMin()) / width);

      if (getLowerBound(bucket) > condVal) {
         assert bucket > 0;
         assert getLowerBound(bucket - 1) <= condVal;

         return bucket - 1;
      } else if (getUpperBound(bucket) < condVal) {
         assert bucket < getArraySize() - 1;
         assert getUpperBound(bucket + 1) >= condVal;

         return bucket + 1;
      }

      assert getLowerBound(bucket) <= condVal && condVal <= getUpperBound(bucket);

      return bucket;
   }

   @Override
   public double getLowerBound(int index) {
      if (index >= getArraySize()) {
         throw new SimulationException("index out of range");
      }

      return getMin() + width * index / getArraySize();
   }

   @Override
   public double getUpperBound(int index) {
      if (index >= getArraySize()) {
         throw new SimulationException("index out of range");
      }

      double bound = getMin() + width * (index + 1) / getArraySize();

      assert bound <= getMax();

      return bound;
   }

   public double getBucketWidth() {
      return width / getArraySize();
   }
}
