/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.support.compression;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.zip.GZIPInputStream;
import java.util.zip.GZIPOutputStream;

public class GZipCompressionProvider implements CompressionProvider {

   @Override
   public InputStream getInputStream(File file) throws FileNotFoundException {
      try {
         return new GZIPInputStream(new FileInputStream(file));
      } catch (IOException e) {
         if (e instanceof FileNotFoundException)
            throw (FileNotFoundException) e;
         else
            throw new RuntimeException("IO Exception was thrown while we tried to read the file " + file.getAbsolutePath(), e);
      }
   }

   @Override
   public OutputStream getOutputStream(File file) throws FileNotFoundException {
      try {
         return new GZIPOutputStream(new FileOutputStream(file));
      } catch (IOException e) {
         if (e instanceof FileNotFoundException)
            throw (FileNotFoundException) e;
         else
            throw new RuntimeException("IO Exception was thrown while we tried to create the file " + file.getAbsolutePath(), e);
      }
   }

}
