/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.untested.statistics.boundary;

import ikr.simlib.result.ResultKeyword;
import ikr.simlib.result.ResultReader;
import ikr.simlib.result.ResultWriter;
import ikr.simlib.result.exceptions.ImportException;
import ikr.simlib.result.exceptions.PrintException;

import java.util.ArrayList;
import java.util.Collections;

public class SortedSamples {

   private static final String EXPORT_NUMBER_OF_SAMPLES = ResultKeyword.asExport("noOfSamples");
   private static final String EXPORT_SAMPLES = ResultKeyword.asExport("samples");
   private static final String EXPORT_SAMPLE = ResultKeyword.asExport("sample");

   private final ArrayList<Double> samples;
   private boolean samplesAreSorted;

   public SortedSamples() {
      samples = new ArrayList<Double>();
      samplesAreSorted = true;
   }

   public void add(double sample) {
      samples.add(sample);
      samplesAreSorted = false;
   }

   public void exportSamples(ResultWriter writer) throws PrintException {
      writer.writeLong(EXPORT_NUMBER_OF_SAMPLES, samples.size());
      writer.writeStartArray(EXPORT_SAMPLES);
      int index = 0;
      for (Double d : samples) {
         writer.writeStartArrayItem(index);
         writer.writeDouble(EXPORT_SAMPLE, d);
         writer.writeEndArrayItem();
         index++;
      }
      writer.writeEndArray();
   }

   public void importSamples(ResultReader reader) throws ImportException {
      long noOfSamples = reader.readLong(EXPORT_NUMBER_OF_SAMPLES);
      reader.readStartArray(EXPORT_SAMPLES);
      for (long i = 0; i < noOfSamples; i++) {
         // read sample
         reader.readStartArrayItem(i);
         double sample = reader.readDouble(EXPORT_SAMPLE);
         reader.readEndArrayItem();

         // update queue
         samples.add(sample);
      }
      reader.readEndArray();
   }

   public double get(int index) {
      if (samplesAreSorted == false) {
         Collections.sort(samples);
         samplesAreSorted = true;
      }
      return samples.get(index);
   }

   public void clear() {
      samples.clear();
      samplesAreSorted = true;
   }

   public int size() {
      return samples.size();
   }
}
