/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.untested.statistics.correlation;

import static ikr.simlib.result.ResultKeywords.BATCH_COEFF;
import static ikr.simlib.result.ResultKeywords.BATCH_COV;
import static ikr.simlib.result.ResultKeywords.COEFF;
import static ikr.simlib.result.ResultKeywords.COEFF_CINT;
import static ikr.simlib.result.ResultKeywords.COV;
import static ikr.simlib.result.ResultKeywords.COV_CINT;
import static ikr.simlib.result.ResultKeywords.LIST;
import ikr.simlib.model.SimNode;
import ikr.simlib.result.PrintResultWriter;
import ikr.simlib.result.Printable;
import ikr.simlib.result.ResultType;
import ikr.simlib.result.exceptions.PrintException;
import ikr.simlib.statistics.Statistic;
import ikr.simlib.statistics.UnweightedSampleCollector;

/**
 * <code>AutoCorrelationStatistic</code> is the base class for auto-correlation
 * statistics.
 */
public abstract class AutoCorrelationStatistic extends Statistic implements Printable, UnweightedSampleCollector<Double> {

   public AutoCorrelationStatistic(SimNode ownNode) {
      super(ownNode);

      simNode.setPrintHandler(this);
   }

   @Override
   public void printResults(ResultType type, PrintResultWriter writer) throws PrintException {
      switch (type) {
      case FINAL:
         writer.writeStartArray(LIST.toString());
         for (int i = 0; i < getLag(); i++) {
            writer.writeStartArrayItem(i);
            writer.writeDouble(COEFF, getCoefficient(i));
            writer.writeDouble(COEFF_CINT, getCoefficientConfidenceInterval(i));
            writer.writeDouble(COV, getCovariance(i));
            writer.writeDouble(COV_CINT, getCovarianceConfidenceInterval(i));
            writer.writeEndArrayItem();
         }
         writer.writeEndArray();
         break;

      case BATCH:
         writer.writeStartArray(LIST.toString());
         for (int i = 0; i < getLag(); i++) {
            writer.writeStartArrayItem(i);
            writer.writeDouble(BATCH_COEFF, getCoefficient(i));
            writer.writeDouble(BATCH_COV, getCovariance(i));
            writer.writeEndArrayItem();
         }
         writer.writeEndArray();
         break;
      }
   }

   public abstract void update(double sample, boolean useValue);

   public final void update(double sample) {
      update(sample, true);
   }

   @Override
   public final void update(Double sample) {
      update(sample.doubleValue());
   }

   public abstract void resetSampleArray();

   public abstract double getCoefficient(int index);

   public abstract double getCoefficientConfidenceInterval(int index);

   public abstract double getCovariance(int index);

   public abstract double getCovarianceConfidenceInterval(int index);

   public abstract double getNoOfSamples(int index);

   public abstract int getLag();
}
