/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.untested.statistics.correlation;

import ikr.simlib.model.SimNode;
import ikr.simlib.result.PrintResultWriter;
import ikr.simlib.result.Printable;
import ikr.simlib.result.ResultKeywords;
import ikr.simlib.result.ResultType;
import ikr.simlib.result.exceptions.PrintException;
import ikr.simlib.statistics.Statistic;

/**
 * <code>CorrelationStatistic</code> is an abstract base class for a cross
 * correlation statistic.
 */
public abstract class CorrelationStatistic extends Statistic implements Printable {

   public CorrelationStatistic(SimNode ownNode) {
      super(ownNode);
      simNode.setPrintHandler(this);
   }

   @Override
   public void printResults(ResultType type, PrintResultWriter writer) throws PrintException {
      switch (type) {
      case FINAL:
         writer.writeDouble(ResultKeywords.COEFF, getCoefficient());
         writer.writeDouble(ResultKeywords.COV, getCovariance());
         writer.writeDouble(ResultKeywords.COEFF_CINT, getCoefficientConfidenceInterval());
         writer.writeDouble(ResultKeywords.COV_CINT, getCovarianceConfidenceInterval());
         break;

      case BATCH:
         writer.writeDouble(ResultKeywords.BATCH_COEFF, getCoefficient());
         writer.writeDouble(ResultKeywords.BATCH_COV, getCovariance());
         break;
      }
   }

   public abstract void update(double xSample, double ySample);

   public abstract double getCoefficient();

   public abstract double getCoefficientConfidenceInterval();

   public abstract double getCovariance();

   public abstract double getCovarianceConfidenceInterval();
}
