/*
 * Copyright (C) 2007-2018 University of Stuttgart, IKR
 * 
 * This file is part of IKR SimLib, Java Edition, as available from
 * http://www.ikr.uni-stuttgart.de/IKRSimLib.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License (LGPL) as published by the
 * Free Software Foundation, in version 2.1 as it comes in the file "COPYING" in
 * directory doc of IKR SimLib.
 * 
 * IKR SimLib is distributed in the hope that it will be useful, but without any
 * warranty of any kind. See the LGPL for details or contact the IKR if you need
 * additional information (http://www.ikr.uni-stuttgart.de).
 * 
 * Alternatively you may license IKR SimLib under a different (non-free)
 * license. Please contact the IKR for further details.
 */

package ikr.simlib.untested.trace;

import ikr.simlib.events.time.Duration;
import ikr.simlib.events.time.PointInTime;

import java.util.Locale;

/**
 * <code>TraceItem</code> represents one line of a trace file.
 */
public class TraceItem {

   protected int hour;
   protected int minutes;
   protected double seconds;
   protected int length;

   public TraceItem(int hour, int minutes, double seconds, int length) {
      this.hour = hour;
      this.minutes = minutes;
      this.seconds = seconds;
      this.length = length;
   }

   public TraceItem() {
   }

   public int getHour() {
      return hour;
   }

   public void setHour(int hour) {
      this.hour = hour;
   }

   public int getMinutes() {
      return minutes;
   }

   public void setMinutes(int minutes) {
      this.minutes = minutes;
   }

   public double getSeconds() {
      return seconds;
   }

   public void setSeconds(double seconds) {
      this.seconds = seconds;
   }

   public int getLength() {
      return length;
   }

   public void setLength(int length) {
      this.length = length;
   }

   @Override
   public String toString() {
      return String.format(Locale.US, "%d:%d:%f %d", hour, minutes, seconds, length);
   }

   public PointInTime getTimeAsPointInTime() {
      return PointInTime.fromSeconds(getSeconds() + 60 * (getMinutes() + 60 * getHour()));
   }

   public Duration getTimeAsDuration() {
      return Duration.fromSeconds(getSeconds() + 60 * (getMinutes() + 60 * getHour()));
   }

}
